@@ -1,7 +1,7 @@
 /****************************************************************************
-** $Id: qt/main.cpp   3.2.1   edited May 13 09:08 $
+** $Id: qt/main.cpp   3.3.6   edited Aug 31 2005 $
 **
-** Copyright (C) 1992-2002 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of an example program for Qt.  This example
 ** program may be used, distributed and modified without limitation.
@@ -22,13 +22,13 @@ int main( int argc, char *argv[] )
 	// Copy data from the oracle database to the ODBC (default)
 	// database
 	QSqlQuery target;
-	QSqlQuery query( "SELECT id, name FROM people;", oracledb );
+	QSqlQuery query( "SELECT id, name FROM people", oracledb );
 	int count = 0;
         if ( query.isActive() ) {
             while ( query.next() ) {
                 target.exec( "INSERT INTO people ( id, name ) VALUES ( " + 
                               query.value(0).toString() + 
-                              ", '" + query.value(1).toString() +  "' );" );
+                              ", '" + query.value(1).toString() +  "' )" );
                 if ( target.isActive() ) 
                     count += target.numRowsAffected();
             }
